@@ -12,8 +12,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
 import unittest
+from unittest import mock
 
 from django.utils.translation import ugettext_lazy as _
 
